import {select,
        csv,
        scaleLinear,
        extent,
        scaleTime,
        axisLeft,
        axisBottom,
       	line,
       	curveBasis} from 'd3';

const svg = d3.select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');   

const render = data =>{
  const Title = 'Temperature in San Francisco'; 
  const xValue = d=>d.timestamp;
	const xAxisLabel = 'Time';
  
  const yValue = d=>d.temperature;
  const yAxisLabel = 'Temperature';
  
  const circleRadius =5;
  const margin = {top:60, right:40 , bottom: 90 , left: 100};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  	.domain(extent(data , xValue))
  	.range([0,innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
		.domain(extent(data , yValue))  	
  	.range([innerHeight,0])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform' ,`translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  		.tickSize(-innerHeight)
  		.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  		.tickSize(-innerWidth)
  		.tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG	
  	.select('.domain')
  		.remove();
  
  yAxisG.append('text')
  		.attr('class','axisLabel')
    	.attr('x',-innerHeight/2)
  		.attr('y',-60)
  		.attr('fill','black')
  		.attr('transform' ,`rotate(-90)`)
			.style('text-anchor','middle')
    	.text(yAxisLabel);
  	
	
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform' ,`translate(0,${innerHeight})`);
 
	xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  		.attr('class','axisLabel')
    	.attr('x',innerWidth/2)
  		.attr('y',75)
  		.attr('fill','black')
  		.text(xAxisLabel);
  
  const lineGenerator = line()
  		.x(d=>xScale(xValue(d)))
  		.y(d=>yScale(yValue(d)))
  		.curve(curveBasis);
  
  g.append('path')
  	.attr('class' , 'line-path')
  	.attr('d',lineGenerator(data));
  
  g.append('text')
  	.attr('class','title')
  	.attr('y',-10)
  	.text(Title);

};
csv('https://gist.githubusercontent.com/NaveenaS12/8894ee44f7a997a0d98d75203746d3f7/raw/temperature-in-san-francisco')
  .then(data => {
  data.forEach(d=>{
    d.temperature =+d.temperature;
    d.timestamp =new Date(d.timestamp);   
  });
	render(data);
});